==> emodpy_covid-0.0.30-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_wfh.py <==
#!/usr/bin/python

import json
import sqlite3
import copy
import random
from pathlib import Path
from . import schema_to_class as s2c

wfh_start_day = 20
min_work_school_group_id=22 # This is very much a function of the scenario configuration (demographics)
max_work_school_group_id=120 # This is very much a function of the scenario configuration (demographics) 
wfh_duration = 60
coverage = 1.0

def app( timestep ):
    # We model working from home by shutting down the Primary transmission route
    # We do this by giving a "Route-Aware Simple Vaccine" to everyone in the Primary groups that represent workplaces.
    # The route that we are applying the vaccine to is CONTACT. It blocks acquisition, transmission (and mortality).
    # We only know that list because we created it. It's not discoverable at runtime yet. It is the last 150 primary ids.
    # 140-289
    
    actual_intervention_name = "RouteAwareSimpleVaccine"
    efficacy_profile = "WaningEffectBox"
    co_event = "WFH"

    # Pretty good boilerplate starts here
    # 1) Gets
    event = s2c.get_default_campaign_event() 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" ) 
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    # Going to use MultiIntervention to distribute intervention and event
    intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    actual_intervention = s2c.get_class_with_defaults( actual_intervention_name ) 
    waning = s2c.get_class_with_defaults( efficacy_profile )
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    # 2) Hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    actual_intervention.Waning_Config = waning 
    intervention.Intervention_List = [ actual_intervention, bcast_intervention ]
    bcast_intervention.Broadcast_Event = co_event
    # ... and boilerplate ends here. This could be standard

    # WHAT?
    actual_intervention.Vaccine_Type = "Generic"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    # HOW MUCH?
    waning.Initial_Effect = 1
    # WHO?
    if coverage != 1.0:
        coordinator.Demographic_Coverage = coverage
    # HOW LONG?
    waning.Box_Duration = wfh_duration
    waning.Initial_Effect = 1 # Initial_Effect default is actually -1 for some reason! :(
    # WHEN?
    if timestep == -1:
        timestep = wfh_start_day
    event.Start_Day = float(timestep) # set from sweep, then by query for number of symptomatics

    campaign = {}
    campaign["Events"] = []
    for prop_id in range(min_work_school_group_id,max_work_school_group_id):
        new_coord = s2c.ReadOnlyDict( copy.deepcopy( json.loads(json.dumps(event.Event_Coordinator_Config))) );
        prop = []
        prop.append( "Primary:" + str( prop_id ) )
        new_coord.Property_Restrictions = prop
        new_event = s2c.get_default_campaign_event() 
        new_event.Event_Coordinator_Config = new_coord
        new_event.Start_Day = float(timestep)
        campaign["Events"].append( new_event )
    new_camp_filename = "wfh.json"

    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file )
    return new_camp_filename

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_wfh.py <==
#!/usr/bin/python

import json
import sqlite3
import copy
import random
from pathlib import Path
from . import schema_to_class as s2c

wfh_start_day = 20
min_work_school_group_id=22 # This is very much a function of the scenario configuration (demographics)
max_work_school_group_id=120 # This is very much a function of the scenario configuration (demographics) 
wfh_duration = 60
coverage = 1.0
debug = False

def app( timestep ):
    # We model working from home by shutting down the Primary transmission route
    # We do this by giving a "Route-Aware Simple Vaccine" to everyone in the Primary groups that represent workplaces.
    # The route that we are applying the vaccine to is CONTACT. It blocks acquisition, transmission (and mortality).
    # We only know that list because we created it. It's not discoverable at runtime yet. It is the last 150 primary ids.
    # 140-289
    
    actual_intervention_name = "RouteAwareSimpleVaccine"
    efficacy_profile = "WaningEffectBox"
    co_event = "WFH"

    # Pretty good boilerplate starts here
    # 1) Gets
    event = s2c.get_default_campaign_event() 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" ) 
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    # Going to use MultiIntervention to distribute intervention and event
    intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    actual_intervention = s2c.get_class_with_defaults( actual_intervention_name ) 
    waning = s2c.get_class_with_defaults( efficacy_profile )
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    # 2) Hook them up
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    actual_intervention.Waning_Config = waning 
    intervention.Intervention_List = [ actual_intervention, bcast_intervention ]
    bcast_intervention.Broadcast_Event = co_event
    # ... and boilerplate ends here. This could be standard

    # WHAT?
    actual_intervention.Vaccine_Type = "Generic"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    actual_intervention.Intervention_Name = co_event
    actual_intervention.Duplicate_Policy = "Replace"
    # HOW MUCH?
    waning.Initial_Effect = 1
    # WHO?
    if coverage != 1.0:
        coordinator.Demographic_Coverage = coverage
    # HOW LONG?
    waning.Box_Duration = wfh_duration
    waning.Initial_Effect = 1 # Initial_Effect default is actually -1 for some reason! :(

    coordinator.finalize()
    intervention.finalize()
    actual_intervention.finalize()
    bcast_intervention.finalize()
    waning.finalize()

    # WHEN?
    if timestep == -1:
        timestep = wfh_start_day
    event.Start_Day = float(timestep) # set from sweep, then by query for number of symptomatics

    campaign = {}
    campaign["Events"] = []
    for prop_id in range(min_work_school_group_id,max_work_school_group_id+1):
        new_coord = s2c.ReadOnlyDict( copy.deepcopy( json.loads(json.dumps(event.Event_Coordinator_Config))) );
        prop = []
        prop.append( "Primary:" + str( prop_id ) )
        new_coord.Property_Restrictions = prop
        new_event = s2c.get_default_campaign_event() 
        new_event.Event_Coordinator_Config = new_coord
        new_event.Start_Day = float(timestep)
        campaign["Events"].append( new_event )

    new_camp_filename = "wfh"
    if debug:
        new_camp_filename += "_" + str(timestep) 
    new_camp_filename += ".json"

    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return new_camp_filename
